from distutils.core import setup
setup(
name = 'MyNesterV2',
version = '2.5.0',
py_modules = ['MyNesterV2'],
author = 'kira02',
author_email = 'hfpython@headfirstlabs.com',
url = 'http://www.headfirstlabs.com',
description = 'A complex printer of nested lists',
)
